@@ -148,14 +148,11 @@ gtr_notebook_new ()
 void
 gtr_notebook_add_page (GtrNotebook * notebook, GtrTab * tab)
 {
-  GtrPo *po;
   GtkWidget *label;
 
   g_return_if_fail (GTR_IS_NOTEBOOK (notebook));
   g_return_if_fail (GTR_IS_TAB (tab));
 
-  po = gtr_tab_get_po (tab);
-
   label = create_tab_label (notebook, tab);
 
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), GTK_WIDGET (tab), label);
@@ -194,7 +191,7 @@ gtr_notebook_remove_page (GtrNotebook * notebook, gint page_num)
  * 
  * Gets the selected page in the #GtrNotebook.
  * 
- * Returns: the selected page in the @notebook
+ * Returns: (transfer none): the selected page in the @notebook
  */
 GtrTab *
 gtr_notebook_get_page (GtrNotebook * notebook)
